@@ -152,10 +152,22 @@ _dbus_server_listen_platform_specific (DBusAddressEntry *entry,
               return DBUS_SERVER_LISTEN_DID_NOT_CONNECT;
             }
 
-          if (!_dbus_string_append (&filename,
-                                    "dbus-") ||
-              !_dbus_generate_random_ascii (&filename, 10) ||
-              !_dbus_string_append (&full_path, tmpdir) ||
+          if (!_dbus_string_append (&filename, "dbus-"))
+            {
+              _dbus_string_free (&full_path);
+              _dbus_string_free (&filename);
+              dbus_set_error (error, DBUS_ERROR_NO_MEMORY, NULL);
+              return DBUS_SERVER_LISTEN_DID_NOT_CONNECT;
+            }
+
+          if (!_dbus_generate_random_ascii (&filename, 10, error))
+            {
+              _dbus_string_free (&full_path);
+              _dbus_string_free (&filename);
+              return DBUS_SERVER_LISTEN_DID_NOT_CONNECT;
+            }
+
+          if (!_dbus_string_append (&full_path, tmpdir) ||
               !_dbus_concat_dir_and_file (&full_path, &filename))
             {
               _dbus_string_free (&full_path);
@@ -199,7 +211,8 @@ _dbus_server_listen_platform_specific (DBusAddressEntry *entry,
     }
   else if (strcmp (method, "systemd") == 0)
     {
-      int i, n, *fds;
+      int i, n;
+      DBusSocket *fds;
       DBusString address;
 
       n = _dbus_listen_systemd_sockets (&fds, error);
@@ -223,13 +236,14 @@ _dbus_server_listen_platform_specific (DBusAddressEntry *entry,
             goto systemd_err;
         }
 
-      *server_p = _dbus_server_new_for_socket (fds, n, &address, NULL);
+      *server_p = _dbus_server_new_for_socket (fds, n, &address, NULL, error);
       if (*server_p == NULL)
-        goto systemd_oom;
+        goto systemd_err;
 
       dbus_free (fds);
 
       return DBUS_SERVER_LISTEN_OK;
+
   systemd_oom:
       _DBUS_SET_OOM (error);
   systemd_err:
@@ -289,7 +303,7 @@ _dbus_server_new_for_domain_socket (const char     *path,
                                     DBusError      *error)
 {
   DBusServer *server;
-  int listen_fd;
+  DBusSocket listen_fd;
   DBusString address;
   char *path_copy;
   DBusString path_str;
@@ -327,18 +341,17 @@ _dbus_server_new_for_domain_socket (const char     *path,
         }
     }
 
-  listen_fd = _dbus_listen_unix_socket (path, abstract, error);
+  listen_fd.fd = _dbus_listen_unix_socket (path, abstract, error);
 
-  if (listen_fd < 0)
+  if (listen_fd.fd < 0)
     {
       _DBUS_ASSERT_ERROR_IS_SET (error);
       goto failed_1;
     }
 
-  server = _dbus_server_new_for_socket (&listen_fd, 1, &address, 0);
+  server = _dbus_server_new_for_socket (&listen_fd, 1, &address, 0, error);
   if (server == NULL)
     {
-      dbus_set_error (error, DBUS_ERROR_NO_MEMORY, NULL);
       goto failed_2;
     }
 
